@@ -648,7 +648,7 @@ glade_editor_load_signal_page (GladeEditor * editor)
 {
   if (editor->priv->signal_editor == NULL)
     {
-      editor->priv->signal_editor = glade_signal_editor_new ((gpointer) editor);
+      editor->priv->signal_editor = glade_signal_editor_new ();
       gtk_container_add (GTK_CONTAINER (editor->priv->page_signals),
                          GTK_WIDGET (editor->priv->signal_editor));
     }
@@ -893,6 +893,7 @@ glade_editor_query_dialog (GladeWidget * widget)
 {
   GladeWidgetAdaptor *adaptor;
   GtkWidget *dialog, *editable, *content_area;
+  GtkWidget *create;
   gchar *title;
   gint answer;
   gboolean retval = TRUE;
@@ -906,9 +907,14 @@ glade_editor_query_dialog (GladeWidget * widget)
                                         GTK_DIALOG_MODAL |
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+                                        NULL);
   g_free (title);
 
+  create = gtk_button_new_with_mnemonic (_("Crea_te"));
+  gtk_widget_show (create);
+  gtk_widget_set_can_default (create, TRUE);
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), create, GTK_RESPONSE_OK);
+
   gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
                                            GTK_RESPONSE_OK,
                                            GTK_RESPONSE_CANCEL, -1);
