@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* TODO : s/glade_xml_get_/glade_xml_node_get/g */
 #ifndef __GLADE_XML_UTILS_H__
 #define __GLADE_XML_UTILS_H__
@@ -21,20 +20,10 @@ typedef struct _GladeXmlDoc     GladeXmlDoc;
 
 /* FIXME: forward declarations to get around circular header dependencies.
  */
-typedef struct _GladeWidget    GladeWidget;
-typedef struct _GladeProperty  GladeProperty;
-typedef struct _GladeProject   GladeProject;
-
-
-/* We define this here only because our headers need
- * a good sorting
- */
-typedef enum
-{
-	GLADE_PROJECT_FORMAT_LIBGLADE,
-	GLADE_PROJECT_FORMAT_GTKBUILDER
-} GladeProjectFormat;
-
+typedef struct _GladeWidget         GladeWidget;
+typedef struct _GladeWidgetAdaptor  GladeWidgetAdaptor;
+typedef struct _GladeProperty       GladeProperty;
+typedef struct _GladeProject        GladeProject;
 
 typedef enum {
 	GLADE_POLICY_PROJECT_WIDE = 0,    /* widget names are unique throughout the project */
@@ -42,14 +31,6 @@ typedef enum {
 } GladeNamingPolicy;
 
 
-#define GLADE_XML_TAG_PROJECT(type) \
-	((type == GLADE_PROJECT_FORMAT_LIBGLADE) ? \
-	 GLADE_XML_TAG_LIBGLADE_PROJECT : GLADE_XML_TAG_BUILDER_PROJECT)
-
-#define GLADE_XML_TAG_WIDGET(type) \
-	((type == GLADE_PROJECT_FORMAT_LIBGLADE) ? \
-	 GLADE_XML_TAG_LIBGLADE_WIDGET : GLADE_XML_TAG_BUILDER_WIDGET)
-
 #define GLADE_GTKBUILDER_VERSIONING_BASE_MAJOR    2
 #define GLADE_GTKBUILDER_VERSIONING_BASE_MINOR    14
 #define GLADE_GTKBUILDER_HAS_VERSIONING(maj, min) \
@@ -58,10 +39,8 @@ typedef enum {
 
 
 /* Used for catalog tags and attributes */
-#define GLADE_XML_TAG_LIBGLADE_PROJECT            "glade-interface"
-#define GLADE_XML_TAG_BUILDER_PROJECT             "interface"
-#define GLADE_XML_TAG_LIBGLADE_WIDGET             "widget"
-#define GLADE_XML_TAG_BUILDER_WIDGET              "object"
+#define GLADE_XML_TAG_PROJECT                     "interface"
+#define GLADE_XML_TAG_WIDGET                      "object"
 
 #define GLADE_XML_TAG_VERSION                     "version"
 #define GLADE_XML_TAG_REQUIRES                    "requires"
@@ -94,12 +73,6 @@ typedef enum {
 #define GLADE_TAG_BUILDER_SINCE                   "gtkbuilder-since"
 #define GLADE_TAG_DEPRECATED                      "deprecated"
 
-#define GLADE_TAG_LIBGLADE_ONLY                   "libglade-only"
-#define GLADE_TAG_LIBGLADE_UNSUPPORTED            "libglade-unsupported"
-#define GLADE_TAG_SUPPORTS                        "supports"
-#define GLADE_TAG_GTKBUILDER                      "gtkbuilder"
-#define GLADE_TAG_LIBGLADE                        "libglade"
-
 #define GLADE_TAG_GLADE_CATALOG                   "glade-catalog"
 #define GLADE_TAG_GLADE_WIDGET_CLASSES            "glade-widget-classes"
 #define GLADE_TAG_GLADE_WIDGET_CLASS              "glade-widget-class"
@@ -118,8 +91,8 @@ typedef enum {
 #define GLADE_TAG_CONSTRUCT_ONLY                  "construct-only"
 #define GLADE_TAG_NEEDS_SYNC                      "needs-sync"
 #define GLADE_TAG_DEFAULT_PALETTE_STATE           "default-palette-state"
-#define GLADE_TAG_PROJECT_CONVERT_FUNCTION        "project-convert-function"
 #define GLADE_TAG_REPLACE_CHILD_FUNCTION          "replace-child-function"
+#define GLADE_TAG_CREATE_WIDGET_FUNCTION          "create-widget-function"
 #define GLADE_TAG_CONSTRUCT_OBJECT_FUNCTION       "construct-object-function"
 #define GLADE_TAG_DEEP_POST_CREATE_FUNCTION       "deep-post-create-function"
 #define GLADE_TAG_POST_CREATE_FUNCTION            "post-create-function"
@@ -155,8 +128,6 @@ typedef enum {
 #define GLADE_TAG_MIN_VALUE                       "min"
 #define GLADE_TAG_VALUE_TYPE                      "value-type"
 #define GLADE_TAG_TOOLTIP                         "tooltip"
-#define GLADE_TAG_PARAMETERS                      "parameters"
-#define GLADE_TAG_PARAMETER                       "parameter"
 #define GLADE_TAG_SET_FUNCTION                    "set-property-function"
 #define GLADE_TAG_GET_FUNCTION                    "get-property-function"
 #define GLADE_TAG_VERIFY_FUNCTION                 "verify-function"
@@ -188,14 +159,13 @@ typedef enum {
 #define GLADE_TAG_SAVE_ALWAYS                     "save-always"
 #define GLADE_TAG_EDITABLE                        "editable"
 #define GLADE_TAG_IGNORE                          "ignore"
-#define GLADE_TAG_VISIBLE_LINES                   "visible-lines"
+#define GLADE_TAG_MULTILINE                       "multiline"
 #define GLADE_TAG_RESOURCE                        "resource"
 #define GLADE_TAG_STOCK                           "stock"
 #define GLADE_TAG_STOCK_ICON                      "stock-icon"
 #define GLADE_TAG_THEMED_ICON                     "themed-icon"
 #define GLADE_TAG_INIT_FUNCTION                   "init-function"
 #define GLADE_TAG_ATK_PROPERTY                    "atk-property"
-#define GLADE_TAG_FIXED                           "fixed"
 #define GLADE_TAG_TRANSFER_ON_PASTE               "transfer-on-paste"
 #define GLADE_TAG_WEIGHT                          "weight"
 #define GLADE_TAG_GET_TYPE_FUNCTION               "get-type-function"
